JsDoc: simile-ajax-api.js

Library: simile-ajax-api.js
Overview
No overview provided.
Constructors
Functions
SimileAjax.prefixURLs(urls, urlPrefix, suffixes)
Append into urls each string in suffixes after prefixing it with urlPrefix.
parameters

Array | urls |
String | urlPrefix |
Array | suffixes |

SimileAjax.parseURLParameters(url, to, types)
Parse out the query parameters from a URL
parameters

String | url | the url to parse, or location.href if undefined
Object | to | optional object to extend with the parameters
Object | types | optional object mapping keys to value types (String, Number, Boolean or Array, String by default)

returns

| a key/value Object whose keys are the query parameter names

Objects
Generated by JsDoc Toolkit on Tue, 07 Aug 2007 20:53:48 GMT